#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import json
import logging

"""
    Utility module for accessing JSON metadata
"""

logger = logging.getLogger("ingestion")


class JSONMetadata:
    def __init__(self, filename):
        self._source_file = filename
        self.from_json(filename)

    def to_json(self, filename):
        """
        Save object in JSON file
        :param filename: file to store object
        :return: None
        """
        with open(filename, "w") as metadata_file:
            return json.dump(self, metadata_file, default=lambda o: o.__dict__, sort_keys=True, indent=4)

    def from_json(self, filename):
        """
        Load object from JSON file
        :param filename: file name of JSON file containing object attributes
        :return: None
        """
        try:
            with open(filename, "r") as metadata_file:
                self.__dict__ = json.load(metadata_file)
        except IOError:
            logger.critical("Error processing file: {}".format(filename))
            exit(-2)

    # Field accessors

    def get_collection_name(self):
        return self.collection_name

    def get_calibration_level(self):
        return self.calibration_level

    def get_starttime(self):
        return self.starttime

    def get_endtime(self):
        return self.endtime

    def get_exposure_time(self):
        return self.exposure_time

    def get_image_tags(self):
        return self.image_tags

    def get_product_tags(self):
        return self.product_tags

    def get_configurations(self):
        return str(self.configurations)

    def get_band_code(self):
        return self.band_code

    def get_project_code(self):
        return self.project_code

    def get_rms_noise(self):
        return self.rms_noise

    def isRealFast(self):
        return self.get_collection_name() == "realfast_execution_blocks"


def test1():
    filename = "metadata1.json"
    o1 = JSONMetadata()
    o2 = JSONMetadata()
    o1.collection_name = "vlass"
    o1.calibration_level = 2
    o1.starttime = None
    o1.endtime = None
    o1.exposure_time = None
    o1.image_tags = ""
    o1.product_tags = ""
    o1.configurations = str(["VLA_B"])

    o1.to_json(filename)
    o2.from_json(filename)
    # print(o2.__dict__)
    assert (
        o1.get_collection_name() == o2.get_collection_name()
        and o1.get_calibration_level() == o2.get_calibration_level()
        and o1.get_starttime() == o2.get_starttime()
        and o1.get_endtime() == o2.get_endtime()
        and o1.get_exposure_time() == o2.get_exposure_time()
        and o1.get_image_tags() == o2.get_image_tags()
        and o1.get_product_tags() == o2.get_product_tags()
        and o1.get_configurations() == o2.get_configurations()
    )


if __name__ == "__main__":
    test1()
